@@ -10,7 +10,11 @@ from aiohttp_socks import ProxyConnector
 from aiokit import AioThing
 from izihawa_utils.common import filter_none
 from multidict import CIMultiDict
-from python_socks import parse_proxy_url
+from python_socks import (
+    ProxyError,
+    ProxyTimeoutError,
+    parse_proxy_url,
+)
 from tenacity import (
     before_sleep_log,
     retry,
@@ -114,6 +118,7 @@ class BaseClient(AioThing):
         if headers:
             all_headers.update(headers)
         all_headers.update(self.headers(**kwargs))
+        full_url = f"{self.base_url}/{url.lstrip('/')}"
 
         try:
             await self.pre_request_hook()
@@ -126,7 +131,7 @@ class BaseClient(AioThing):
 
             response = await self.session.request(
                 method,
-                f"{self.base_url}/{url.lstrip('/')}",
+                full_url,
                 params=params,
                 headers=filter_none(all_headers),
                 data=data,
@@ -136,20 +141,23 @@ class BaseClient(AioThing):
                 return await response_processor(response)
             return response
         except ClientConnectorError as e:
-            if isinstance(e.os_error, socket.gaierror) and e.errno == -2:
-                raise TemporaryError(url=url, nested_error=str(e))
-            elif e.errno == 111:
-                raise TemporaryError(url=url, nested_error=str(e))
+            if isinstance(e.os_error, socket.gaierror) and (e.errno == -2 or e.errno == 111):
+                await self.session.close()
+                self.session = self._create_session()
+                raise TemporaryError(url=full_url, nested_error=str(e))
             else:
                 raise
         except (
             aiohttp.client_exceptions.ClientOSError,
             aiohttp.client_exceptions.ServerDisconnectedError,
             asyncio.TimeoutError,
+            ConnectionAbortedError,
+            ProxyError,
+            ProxyTimeoutError,
         ) as e:
             await self.session.close()
             self.session = self._create_session()
-            raise TemporaryError(url=url, nested_error=str(e))
+            raise TemporaryError(url=full_url, nested_error=str(e))
 
     async def delete(self, url: str = '', *args, **kwargs):
         return await self.request('delete', url, *args, **kwargs)
@@ -225,9 +233,9 @@ class BaseStandardClient(BaseClient):
         if response.status == 502 or response.status == 503:
             raise ServiceUnavailableError(status=response.status, data=data)
         elif response.status == 404:
-            raise NotFoundError(status=response.status, data=data, url=response.url)
+            raise NotFoundError(status=response.status, data=data, url=str(response.url))
         elif response.status == 405:
-            raise MethodNotAllowedError(status=response.status, url=response.url)
+            raise MethodNotAllowedError(status=response.status, url=str(response.url))
         else:
             if content_type.startswith('application/json'):
                 try:
